auto_gen_assets library

Classes

AssetGenerator
A utility class for automatically generating Dart code for assets.
AssetItem
Represents an individual asset item with its name and path.
AssetWatcher
Watcher class for auto-generating assets when files change

Functions

main(List<String> args) → void
Command line interface for the watcher