AssetItem class

Represents an individual asset item with its name and path.

Constructors

AssetItem({required String name, required String path})
Creates an AssetItem with the given name and path.
const

Properties

hashCode int
The hash code for this object.
no setteroverride
name String
The camelCase name of the asset for use in code.
final
path String
The relative path to the asset file.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override