AssetWatcher class

Watcher class for auto-generating assets when files change

Constructors

AssetWatcher({String assetsDirectory = 'assets', String outputFile = 'lib/generated/assets.dart', String className = 'Assets', bool ignoreHiddenFiles = true, bool ignoreEnvFiles = true})

Properties

assetsDirectory String
final
className String
final
hashCode int
The hash code for this object.
no setterinherited
ignoreEnvFiles bool
final
ignoreHiddenFiles bool
final
outputFile String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
watch() Future<void>
Start watching the assets directory for changes

Operators

operator ==(Object other) bool
The equality operator.
inherited